<?php

	/* ------------------------------------
	:: ENQUEUE SCRIPTS
	------------------------------------ */

	function acoda_scripts()
	{
		if ( !is_admin() )
		{
			wp_enqueue_style( 'acoda-style', get_bloginfo('stylesheet_url'), false, null );
			
			wp_enqueue_script( 'jquery-ui-core', false, array('jquery') );
			wp_enqueue_script( 'jquery-effects-core', false, array('jquery') );
			
			wp_enqueue_script( 'waypoints', get_template_directory_uri().'/js/waypoints.min.js', array('jquery'), true );		
	
			if( of_get_option('lightbox_script') != 'disable' )
			{
				$classes = ( of_get_option('lightbox_classes') != '' ? rtrim( of_get_option('lightbox_classes'), ',') : '' );
				
				$lightbox_options = array(
					'classes'		=> $classes,
				);
				
				wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri().'/js/jquery.fancybox.min.js', false, array('jquery'), true );
				wp_localize_script('jquery-fancybox', 'LIGHTBOX_OPTIONS', $lightbox_options );
			}
			
			// Acoda Page Animate
			$page_animate_type = acoda_global_vars('page_animate_type');	
						
			if( !empty( $page_animate_type ) )
			{
				wp_enqueue_style('acoda-page-animate', get_template_directory_uri().'/css/acoda-page-animate.css',false );		
	
				wp_enqueue_script(
					'acoda-page-animate',
					get_template_directory_uri().'/js/acoda-page-animate.min.js',
					false,
					array(
						'jquery',
						'acoda-script'
					),
					true
				);
	
				wp_enqueue_script(
					'touch-gestures',
					get_template_directory_uri().'/js/touch.gestures.min.js',
					false,
					array( 'jquery' ),
					true
				);	
			}

			$acoda_skin = acoda_global_vars('skin');
			$get_skin_data = maybe_unserialize( get_option('skin_data_'. $acoda_skin ) );
			$acoda_skin_logo_retina = ( !empty( $get_skin_data['skin_id_header_logo_retina'] ) ) ? $get_skin_data['skin_id_header_logo_retina'] : '';	
			$acoda_skin_logo_retina_transparent = ( !empty( $get_skin_data['skin_id_logo_transparent_retina'] ) ) ? $get_skin_data['skin_id_logo_transparent_retina'] : '';			
			
			$branding_retina = ( ! empty( $acoda_skin_logo_retina ) ? $acoda_skin_logo_retina : ( of_get_option( 'branding_2x' ) != '' ? of_get_option( 'branding_2x' ) : '' ) );
	
			$theme_options = array(
				'template_url'	=> get_template_directory_uri(),
				'branding_2x'	=> $branding_retina,	
				'branding_2x_transparent'	=> $acoda_skin_logo_retina_transparent,	
			);
	
			wp_enqueue_script( 'acoda-script', get_template_directory_uri().'/js/acoda-script.pack.js', false, array('jquery'), true );
			wp_localize_script('acoda-script', 'THEME_OPTIONS', $theme_options );
		
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			{
				wp_enqueue_script( 'comment-reply' );
			}	
		
			// Remove Contact Form 7 Styling
			wp_deregister_style('contact-form-7');		
	
			
			// Sticky Header
			$acoda_sticky_menu = acoda_global_vars('sticky_menu');	
			
			if( $acoda_sticky_menu != 'disable' )
			{
				wp_enqueue_script( 'waypoints-sticky', get_template_directory_uri().'/js/waypoints-sticky.min.js', array('jquery','waypoints'), true );
			}
			
			/* ------------------------------------
			:: IE SCRIPTS / STYLES
			------------------------------------ */ 
			
			wp_enqueue_script('respond', get_template_directory_uri().'/js/respond.min.js',false );		
			wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );											

		}
		
		// Font Awesome
		wp_enqueue_style('font-awesome', get_template_directory_uri().'/css/font-icons/fontawesome/css/fontawesome-all.min.css',false,null );
	}    

	add_action( 'wp_enqueue_scripts', 'acoda_scripts', 101 );


	/* ------------------------------------
	:: THEME SETUP
	------------------------------------ */
	
	function acoda_theme_setup()
	{		
		/* ------------------------------------
		:: THEME PREFIX * DO NOT CHANGE *
		------------------------------------ */
	
		define( 'ACODA_THEME_PREFIX', 'YOU' ); 
		update_option( 'acoda_theme', ACODA_THEME_PREFIX );
	
		/* ------------------------------------
		:: CORE FUNCTIONS
		------------------------------------ */
	
		require_once get_template_directory() . '/functions-core.php';
		
		/* ------------------------------------
		:: THEME OPTIONS
		------------------------------------ */
		
		define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/lib/adm/options-framework/inc/' );
		require_once get_template_directory() . '/lib/adm/options-framework/inc/options-framework.php';
		require_once get_template_directory() . '/options.php';
		require_once get_template_directory() . '/lib/adm/metabox-options/options-meta.php';
		require_once get_template_directory() . '/lib/adm/inc/options-backup.php';
	
		/* ------------------------------------
		:: TGM PLUGIN ACTIVATION
		------------------------------------ */
	
		require_once get_template_directory() . '/lib/adm/inc/class-tgm-plugin-activation.php';
	
		/* ------------------------------------
		:: THEME SETUP
		------------------------------------ */	
		
		require_once get_template_directory().'/theme-setup.php';
	
		/* ------------------------------------
		:: CUSTOM WIDGETS
		------------------------------------ */	
		
		require_once get_template_directory() .'/lib/adm/inc/custom-widgets.php';
	
		/* ------------------------------------
		:: BREADCRUMBS
		------------------------------------ */
	
		require_once get_template_directory() .'/lib/inc/breadcrumbs.php';
	
		/* ------------------------------------
		:: TITLE TAG
		------------------------------------ */	
		
		add_theme_support( 'title-tag' );
	
		/* ------------------------------------
		:: THUMBNAIL + CUSTOM BACKGROUNDS
		------------------------------------ */
	
		add_theme_support( 'post-thumbnails' ); 
	
		/* ------------------------------------
		:: POST FORMATS SUPPORT
		------------------------------------ */
	
		add_theme_support( 'post-formats', array( 'aside', 'link', 'status', 'quote', 'image' , 'video', 'audio', 'gallery' ));
	
		/* ------------------------------------
		:: AUTOMATIC FEED LINKS
		------------------------------------ */
	
		add_theme_support( 'automatic-feed-links' );
		
		
		/* ------------------------------------
		:: TRANSLATION
		------------------------------------ */
	
		load_theme_textdomain( 'you', get_template_directory() . '/languages' );
	
		$locale = get_locale();
		$locale_file = get_template_directory() . "/languages/$locale.php";
		
		if ( is_readable( $locale_file ) )
		{
			require_once( $locale_file );
		}
	
		/* ------------------------------------
		:: BUILD SKIN PRESETS + CUSTOMIZER
		------------------------------------ */
	
		acoda_skin_presets();
		
		require_once get_template_directory() .'/lib/adm/inc/theme-customizer.php';		
	
		/* ------------------------------------
		:: VISUAL COMPOSER EXTENDED
		------------------------------------ */
		
		require_once get_template_directory() .'/lib/inc/shortcodes.php';
		
		/* ------------------------------------
		:: WOOCOMMERCE
		------------------------------------ */
		
		add_theme_support( 'wc-product-gallery-zoom' );
    	add_theme_support( 'wc-product-gallery-lightbox' );
    	add_theme_support( 'wc-product-gallery-slider' );
	}
	
	add_action( 'after_setup_theme', 'acoda_theme_setup' );	