<?php
/**
 * Include and setup custom metaboxes (cmb) and fields.
 *
 * @category ACODA
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress
 */

add_filter( 'cmb_meta_boxes', 'acoda_metaboxes' );
/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */
function acoda_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_'. ACODA_THEME_PREFIX .'_';

	// Sidebar Array
	if( !of_get_option('sidebars_num') ) $sidebars = '2'; else $sidebars = of_get_option('sidebars_num');
	
	for( $i=1; $i<=$sidebars; $i++ )
	{
		$sidebar_array[$i] = array( 'name' => 'Sidebar '.$i, 'value' => 'Sidebar'.$i, );
	}
	
	// Get Menus
	$menus = get_terms('nav_menu');
	
	$menu_array[] = array( 'name' => 'Default', 'value' => '', );
	
	foreach( $menus as $value )
	{
		$menu_array[$value->name] = array( 'name' => $value->name, 'value' => $value->name, );
	} 
	
	$menu_array[] = array( 'name' => 'Disable', 'value' => 'disable', );

	// Skin ID's
	$skin_ids = explode(',', rtrim( get_option('skins_you_ids'), ',' ) );
	
	$skin_id_array[] = array( 'name' => 'Select Skin', 'value' =>'' );
	
	foreach( $skin_ids as $skin_id )
	{
		$skin_id_array[] = array( 'name' => $skin_id, 'value' => $skin_id, );
	}
	

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/lib/adm/images/';	
	
	$meta_boxes[] = array(
		'id'         => 'x_post_metabox',
		'title'      => esc_html__( 'General', 'you' ),
		'pages'      => array( 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(	
			array(
				'name'    => esc_html__( 'Display Title', 'you' ),
				'id'      => $prefix . 'displaytitle',
				'type'    => 'radio_inline',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),		
			array(
				'name' => esc_html__( 'Alternative Page Title', 'you' ),
				'plac' => '',
				'id'   => $prefix . 'pagetitle',
				'type' => 'text',
			),	
			array(
				'name' => esc_html__( 'Sub Title', 'you' ),
				'desc' => '',
				'plac' => '',
				'id'   => $prefix . 'pagesubtitle',
				'type' => 'text',
			),		
			array(
				'name'    => esc_html__( 'Breadcrumbs', 'you' ),
				'id'      => $prefix . 'hidebreadcrumbs',
				'type'    => 'radio_inline',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),
			array(
				'name'     => esc_html__( 'Share + Related Posts', 'you' ),
				'id'       => $prefix . 'share_related',
				'type'     => 'title',
			),				
			array(
				'name'    => esc_html__( 'Share Post', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'share_post',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Related Posts', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'related_posts',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),										
			array(
				'name'     => esc_html__( 'Featured Image Display', 'you' ),
				'id'       => $prefix . 'featured_image',
				'type'     => 'title',
			),						
			array(
				'name'    => esc_html__( 'Featured Image', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'postshowimage',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),												
		)
	);

	$meta_boxes[] = array(
		'id'         => 'x_post_metadata',
		'title'      => esc_html__( 'Post Metadata', 'you' ),
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(	
			array(
				'name'     => esc_html__( 'Display Post Metadata', 'you' ),
				'id'       => $prefix . 'post_metadata',
				'type'     => 'title',
			),		
			array(
				'name'    => esc_html__( 'Date', 'you' ),
				'id'      => $prefix . 'meta_date',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),
			array(
				'name'    => esc_html__( 'Author', 'you' ),
				'id'      => $prefix . 'meta_author',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),			
			array(
				'name'    => esc_html__( 'Categories', 'you' ),
				'id'      => $prefix . 'meta_categories',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Tags', 'you' ),
				'id'      => $prefix . 'meta_tags',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Like', 'you' ),
				'id'      => $prefix . 'meta_like',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),
			array(
				'name'    => esc_html__( 'Comments', 'you' ),
				'id'      => $prefix . 'meta_comments',
				'type'    => 'select',
				'size'	  => 'medium',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Single', 'you' ), 'value' => 'single', ),
					array( 'name' => esc_html__( 'Archive', 'you' ), 'value' => 'archive', ),
					array( 'name' => esc_html__( 'Single + Archive', 'you' ), 'value' => 'singlearchive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),			
		)
	);										

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/lib/adm/images/';	
	
	$meta_boxes[] = array(
		'id'         => 'x_page_metabox',
		'title'      => esc_html__( 'General', 'you' ),
		'pages'      => array( 'page' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(	
			array(
				'name'  =>  esc_html__( 'Display Title', 'you' ),
				'id'    => $prefix . 'displaytitle',
				'type'  => 'radio_inline',
				'size'	 => 'medium',
				'std'	 => '',
				'options' => array(
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),			
			array(
				'name' => esc_html__( 'Alternative Page Title', 'you' ),
				'id'   => $prefix . 'pagetitle',
				'type' => 'text',
			),	
			array(
				'name' => esc_html__( 'Sub Title', 'you' ),
				'desc' => '',
				'plac' => '',
				'id'   => $prefix . 'pagesubtitle',
				'type' => 'text',
			),		
			array(
				'name'   => esc_html__( 'Breadcrumbs', 'you' ),
				'id'     => $prefix . 'hidebreadcrumbs',
				'type'   => 'radio_inline',
				'size'	  => 'medium',
				'std'	  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Enable',  'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable',  'you' ),  'value' => 'disable', ),
				),
			),																										
		)
	);	
	

	$meta_boxes[] = array(
		'id'         => 'x_layout_metabox',
		'title'      => esc_html__( 'Layout', 'you' ),
		'pages'      => array( 'page', 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name'     => esc_html__( 'General', 'you' ),
				'id'       => $prefix . 'general_title',
				'type'     => 'title',
			),				
			array(
				'name'    => esc_html__( 'Site Layout', 'you' ),
				'id'      => $prefix . 'site_layout',
				'type'    => 'radio_inline',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Wide', 'you' ), 'value' => 'wide', ),
					array( 'name' => esc_html__( 'Boxed', 'you' ), 'value' => 'boxed', ),
				),
			),							
			array(
				'name'    => esc_html__( 'Page Layout', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'layout',
				'type'    => 'radio',
				'std'		  => '',
				'options' => array(
					'' => array(
						'path' => $imagepath . 'layout-0.png',
						'name' => esc_html__( 'Default', 'you' ),
					 ),
					'layout_zero' => array(
						'path' => $imagepath . 'layout-1.png',
						'name' => esc_html__( 'Full Width', 'you' ),
					 ),
					'layout_one' => array(
						'path' => $imagepath . 'layout-1.png',
						'name' => esc_html__( 'No Sidebar', 'you' ),
					 ),
					'layout_two' => array(
						'path' => $imagepath . 'layout-2.png',
						'name' => esc_html__( '1x Left Sidebar', 'you' ),
					 ),	
					'layout_three' => array(
						'path' => $imagepath . 'layout-3.png',
						'name' => esc_html__( '2x Left Sidebar', 'you' ),
					 ),
					'layout_four' => array(
						'path' => $imagepath . 'layout-4.png',
						'name' => esc_html__( '1x Right Sidebar', 'you' ),
					 ),
					'layout_five' => array(
						'path' => $imagepath . 'layout-5.png',
						'name' => esc_html__( '2x Right Sidebar', 'you' ),
					 ),	
					'layout_six' => array(
						'path' => $imagepath . 'layout-6.png',
						'name' => esc_html__( 'Left + Right Sidebar', 'you' ),
					 ),						 				 					 				 		 
				),
			),
			array(
				'name'    => esc_html__( 'Column 1 Sidebar', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'sidebar_one',
				'type'    => 'select',
				'std'	  => 'Sidebar1',
				'options' => $sidebar_array
			),	
			array(
				'name'    => esc_html__( 'Column 2 Sidebar', 'you' ),		
				'desc'    => '',
				'id'      => $prefix . 'sidebar_two',
				'type'    => 'select',
				'std'	  => 'Sidebar2',
				'options' => $sidebar_array
			),		
			array(
				'name'     => esc_html__( 'Header / Menu', 'you' ),
				'desc'     => esc_html__( 'These options relate to the Header & Menu areas.', 'you' ),
				'id'       => $prefix . 'headermenu_title',
				'type'     => 'title',
			),	
			array(
				'name'    => esc_html__( 'Dock Bar', 'you' ),	
				'id'      => $prefix . 'dockbar_display',
				'type'    => 'radio_inline',
				'std'		  => 'enable',
				'options' => array(
					array( 'name' => esc_html__( 'Off', 'you' ), 'value' => 'disable', ),
					array( 'name' => esc_html__( 'On', 'you' ), 'value' => 'enable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Header Display', 'you' ), 
				'id'      => $prefix . 'header_display',
				'type'    => 'radio_inline',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Off', 'you' ), 'value' => 'disable', ),
					array( 'name' => esc_html__( 'On', 'you' ), 'value' => 'enable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Sticky Header', 'you' ), 
				'id'      => $prefix . 'sticky_menu',
				'type'    => 'radio_inline',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Off', 'you' ), 'value' => 'disable', ),
					array( 'name' => esc_html__( 'On', 'you' ), 'value' => 'enable', ),
				),
			),					
			array(
				'name'    => esc_html__( 'Horizontal Layout', 'you' ), 
				'id'      => $prefix . 'header_layout',
				'desc' => '',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Logo Left | Menu Right', 'you' ),  'value' => 'layout_1', ),
					array( 'name' => esc_html__( 'Menu Left | Logo Right', 'you' ),  'value' => 'layout_2', ),
					array( 'name' => esc_html__( 'Menu Center | Logo Center', 'you' ), 'value' => 'layout_3', ),
				),
			),
			array(
				'name'    => esc_html__( 'Vertical Layout', 'you' ), 
				'id'      => $prefix . 'header_layout_vertical',
				'desc' => '',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ),  'value' => '', ),
					array( 'name' => esc_html__( 'Top + Auto Height', 'you' ),  'value' => 'vertical_layout_1', ),
					array( 'name' => esc_html__( 'Top + 30% Height', 'you' ), 'value' => 'vertical_layout_1 height_30', ),					
					array( 'name' => esc_html__( 'Top + 50% Height', 'you' ), 'value' => 'vertical_layout_1 height_50', ),
					array( 'name' => esc_html__( 'Top + 100% Height', 'you' ), 'value' => 'vertical_layout_1 height_100', ),
					array( 'name' => esc_html__( 'Middle + 30% Height', 'you' ), 'value' => 'vertical_layout_2 height_30', ),
					array( 'name' => esc_html__( 'Middle + 50% Height', 'you' ), 'value' => 'vertical_layout_2 height_50', ),
					array( 'name' => esc_html__( 'Middle + 100% Height', 'you' ), 'value' => 'vertical_layout_2 height_100', ),
				),
			),								
			array(
				'name' => esc_html__( 'Logo Height', 'you' ), 
				'plac' => '',
				'id'   => $prefix . 'logo_height',
				'type' => 'text_small',
			),	
			array(
				'name' => esc_html__( 'Menu Height', 'you' ), 
				'plac' => '',
				'id'   => $prefix . 'menu_height',
				'type' => 'text_small',
			),	
			array(
				'name' => esc_html__( 'Subheader Height', 'you' ), 
				'plac' => '',
				'id'   => $prefix . 'subheader_height',
				'type' => 'text_small',
			),																	
			array(
				'name'    => esc_html__( 'Floating Header', 'you' ),
				'id'      => $prefix . 'header_float',
				'desc' => esc_html__( 'Enable the header to float over page content, including the option to set to transparent. To set a custom font color, please use the Skin Customizer.', 'you' ),
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'header_float_disabled', ),
					array( 'name' => esc_html__( 'Float', 'you' ), 'value' => 'header_float', ),
					array( 'name' => esc_html__( 'Float + Transparent / Normal Font Color', 'you' ), 'value' => 'header_float transparent_default_font', ),
					array( 'name' => esc_html__( 'Float + Transparent / Custom Font Color', 'you' ), 'value' => 'header_float transparent', ),
					
				),
			),																
			array(
				'name'    => esc_html__( 'Title / Breadcrumbs Layout', 'you' ),
				'id'      => $prefix . 'title_layout',
				'desc' => '',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Title / Breadcrumbs Layout', 'you' ),'Default', 'value' => '', ),
					array( 'name' => esc_html__( 'Title ( Left ) / Breadcrumbs ( Right )', 'you' ), 'value' => 'layout_1', ),
					array( 'name' => esc_html__( 'Breadcrumbs ( Left ) / Title ( Right )', 'you' ), 'value' => 'layout_2', ),
					array( 'name' => esc_html__( 'Title ( Center ) / Breadcrumbs ( Center )', 'you' ), 'value' => 'layout_3', ),
				),
			),
			array(
				'name'    => esc_html__( 'Menu', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'menu',
				'type'    => 'select',
				'options' => $menu_array
			),					
			array(
				'name' => esc_html__( 'Footer', 'you' ),
				'desc' => esc_html__( 'These options relate to the Main & Footer areas.', 'you' ),
				'id'   => $prefix . 'mainfooter_title',
				'type' => 'title',
			),
			array(
				'name'    => esc_html__( 'Footer', 'you' ),
				'id'      => $prefix . 'disablefooter',
				'type'    => 'radio_inline',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Off', 'you' ), 'value' => 'yes', ),
					array( 'name' => esc_html__( 'On', 'you' ), 'value' => '', ),					
				),
			),																							
		),
	);

	$meta_boxes[] = array(
		'id'         => 'x_singlepage_options_metabox',
		'title'      => esc_html__( 'Single Page', 'you' ), 
		'pages'      => array( 'page', ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name'	=> esc_html__( 'Animate Type', 'you' ),
				'id'   	=> $prefix . 'page_animate_type',
				'desc'	=> esc_html__( 'Note: Footer Widgets will be Disabled.', 'you' ),
				'type'	=> 'radio',
				'options' => array(
					array( 'name' => esc_html__( 'Normal', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( '3d Vertical', 'you' ), 'value' => 'page_animate_1', ),
					array( 'name' => esc_html__( '3d Horizontal', 'you' ), 'value' => 'page_animate_2', ),
					array( 'name' => esc_html__( 'Snap Scroll Vertical', 'you' ), 'value' => 'page_animate_3', ),	
					array( 'name' => esc_html__( 'Snap Scroll Horizontal', 'you' ), 'value' => 'page_animate_4', ),	
				),
			),
			array(
				'name'	=> esc_html__( 'Display on Devices', 'you' ),
				'id'   	=> $prefix . 'page_animate_device',
				'type'	=> 'radio',
				'options' => array(
					array( 'name' => esc_html__( 'Desktop & Mobile', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Desktop Only', 'you' ), 'value' => 'desktop', ),
				),
			),					
			array(
				'name'    => esc_html__( 'Bullet Navigation', 'you' ),
				'id'      => $prefix . 'anchorlink_nav',
				'type'    => 'radio_inline',
				'desc'     => esc_html__( 'Enable bullet navigation to each Single page slide.', 'you' ),
				'std'		  => 'disable',
				'options' => array(
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Directional Navigation', 'you' ),
				'id'      => $prefix . 'directional_nav',
				'type'    => 'radio_inline',
				'desc'     => esc_html__( 'Enable Directional Navigation Icons.', 'you' ),
				'std'		  => 'dir-nav-icon',
				'options' => array(
					array( 'name' => esc_html__( 'Icon', 'you' ), 'value' => 'dir-nav-icon', ),
					array( 'name' => esc_html__( 'Icon + Background', 'you' ), 'value' => 'dir-nav-icon-two', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'dir-nav-icon-disabled', ),
				),
			),		
			array(
				'name'    => esc_html__( 'Static Header', 'you' ),
				'id'      => $prefix . 'single_static_header',
				'type'    => 'radio_inline',
				'desc'     => esc_html__( 'Enable Static Header to show the header at all times. This overrides the Sticky Header option.', 'you' ),
				'std'		  => 'disable',
				'options' => array(
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'enable', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'disable', ),
				),
			),								
		)		
	);		

	$meta_boxes[] = array(
		'id'         => 'x_social_metabox',
		'title'      => esc_html__( 'Social', 'you' ),
		'pages'      => array( 'page', 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => acoda_social_options(),
	);

	$meta_boxes[] = array(
		'id'         => 'x_skin_options_metabox',
		'title'      => esc_html__( 'Skin', 'you' ),
		'pages'      => array( 'page', 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name'    => esc_html__( 'Skin', 'you' ),
				'id'      => $prefix . 'customskin',
				'type'    => 'select',
				'options' => $skin_id_array
			),		
		)		
	);		

	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page)
	{
		$options_pages[$page->ID] = $page->post_title;
	}

	$meta_boxes[] = array(
		'id'         => 'x_portfolio_options_metabox',
		'title'      => esc_html__( 'Portfolio', 'you' ),
		'pages'      => array( 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name'    => 'Parent Portfolio Page',
				'id'      => $prefix . 'portfoliopage',
				'desc'    => esc_html__( 'Set a Page to link this Portfolio to. Default is set in Appearance > Theme Options > Portfolio > Portfolio Page Link.', 'you' ),
				'type'    => 'select',
				'options' => $options_pages	
			),		
		)		
	);	
	
	$meta_boxes[] = array(
		'id'         => 'x_blog_metabox',
		'title'      => esc_html__( 'Blog Template', 'you' ),
		'pages'      => array( 'page', ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			array(
				'name'     => esc_html__( 'Blog Template', 'you' ),
				'id'       => $prefix . 'post_metadata',
				'desc'		=> esc_html__( 'Select "Blog Template" from the Template drop down menu under Page Attributes.', 'you' ),
				'type'     => 'title',
			),
			array(
				'name'    => esc_html__( 'Layout Format', 'you' ),
				'id'      => $prefix . 'arhpostdisplay',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Normal', 'you' ), 'value' => 'normal', ),
					array( 'name' => esc_html__( 'Grid', 'you' ), 'value' => 'grid', ),
					array( 'name' => esc_html__( 'Masonry Grid', 'you' ), 'value' => 'masonrygrid', )		
				),
			),	
			array(
				'name'    => esc_html__( 'Boxed Post Style', 'you' ),
				'id'      => $prefix . 'post_layout_style',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'boxed_archive', ),
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'unboxed', ),
				),
			),				
			array(
				'name'    => esc_html__( 'Grid Columns', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'arhpostcolumns',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Two', 'you' ),	'value' => '2', ),
					array( 'name' => esc_html__( 'Three', 'you' ), 'value' => '3', ),
					array( 'name' => esc_html__( 'Four', 'you' ), 'value' => '4', ),
					array( 'name' => esc_html__( 'Five', 'you' ), 'value' => '5', ),
					array( 'name' => esc_html__( 'Six', 'you' ), 'value' => '6', ),
				),
			),			
			array(
				'name'    => esc_html__( 'Search', 'you' ),
				'id'      => $prefix . 'blog_search',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Disabled', 'you' ), 'value' => 'disabled', ),
					array( 'name' => esc_html__( 'Search Bar', 'you' ), 'value' => 'search', ),
					array( 'name' => esc_html__( 'Search Filter', 'you' ), 'value' => 'search_filter', ),
					array( 'name' => esc_html__( 'Search Filter + Highlight', 'you' ), 'value' => 'search_filter_highlight', )		
				),
			),							
			array(
				'name'    => esc_html__( 'Pagination', 'you' ),
				'id'      => $prefix . 'blog_pagination',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Ajax Click Load', 'you' ), 'value' => 'click_load', ),
					array( 'name' => esc_html__( 'Ajax Scroll Load', 'you' ), 'value' => 'scroll_load', ),
					array( 'name' => esc_html__( 'Page Numbers', 'you' ), 'value' => 'page_numbers', )		
				),
			),		
			array(
				'name' => esc_html__( 'Ajax Load Number of Posts', 'you' ),
				'plac' => 'Link post to an alternative URL',
				'id'   => $prefix . 'ajax_num_posts',
				'type' => 'text_small',
			),	
			array(
				'name'     => esc_html__( 'Image Settings', 'you' ),
				'desc'     => esc_html__( 'These settings do not affect Single Post images.', 'you' ),
				'id'       => $prefix . 'blog_image_title',
				'type'     => 'title',
			),	
			array(
				'name'    => esc_html__( 'Image Align', 'you' ),
				'id'      => $prefix . 'archive_img_align',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Left', 'you' ), 'value' => 'left', ),
					array( 'name' => esc_html__( 'Center', 'you' ), 'value' => 'center', ),
					array( 'name' => esc_html__( 'Right', 'you' ), 'value' => 'right', ),
				),
			),	
			array(
				'name'    => esc_html__( 'Image Lightbox', 'you' ),
				'id'      => $prefix . 'blog_lightbox',
				'type'    => 'select',
				'std'		  => 'disable',
				'options' => array(
					array( 'name' => esc_html__( 'Default', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Off', 'you' ), 'value' => 'disable', ),
					array( 'name' => esc_html__( 'On', 'you' ), 'value' => 'enable', ),
				),
			),						
			array(
				'name'    => esc_html__( 'Image Effect', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'archive_img_effect',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'None', 'you' ), 'value' => '', ),
					array( 'name' => esc_html__( 'Frame', 'you' ), 'value' => 'frame', ),
					array( 'name' => esc_html__( 'Black & White', 'you' ),	'value' => 'blackwhite', ),
					array( 'name' => esc_html__( 'Frame + Black & White', 'you' ), 'value' => 'frameblackwhite', ),
				),
			),	
			array(
				'name' => esc_html__( 'Image Size', 'you' ),
				'id'   => $prefix . 'archive_img_size',
				'type' => 'text_small',
				'desc' => esc_html__("Enter image size. e.g. 'thumbnail', 'medium', 'large', 'full'. Alternatively enter image size in pixels: 200x100 (Width x Height).", 'you')
			),								
			array(
				'name'    => esc_html__( 'Select Categories', 'you' ),
				'id'      => $prefix . 'archivecat',
				'class'	  => '',
				'type'    => 'multicheck',
				'options' => acoda_data_source('data-2')
			),
			array(
				'name'    => esc_html__( 'Disable Post Format(s)', 'you' ),
				'id'      => $prefix . 'filter_formats',
				'type'    => 'multicheck',
				'class'   => '',
				'options' => acoda_data_source('data-2-formats', 'blog')
			),						
		),
	);

	
	$meta_boxes[] = array(
		'id'         => 'x_gallery_options_metabox',
		'title'      => esc_html__( 'Media', 'you' ),
		'pages'      => array( 'post', 'portfolio' ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name' => esc_html__( 'Media URL', 'you' ),
				'id'   => $prefix . 'movieurl',
				'type' => 'file',
				'desc'     => esc_html__( "Uses oEmbed to display the Media - you'll need to the Post Format to Video.", 'you' ),
			),
			array(
				'name'    => esc_html__( 'Media Embed Type', 'you' ),
				'desc'    => '',
				'id'      => $prefix . 'videotype',
				'type'    => 'select',
				'std'		  => '',
				'options' => array(
					array( 'name' => esc_html__( 'oEmbed', 'you' ), 'value' => 'oembed', ),
					array( 'name' => esc_html__( 'Lightbox', 'you' ),	'value' => 'lightbox', ),
				),
			),																			
		)
	);

	$meta_boxes[] = array(
		'id'         => 'x_additional_settings_metabox',
		'title'      => esc_html__( 'Additional', 'you' ),
		'pages'      => array( 'post', ), // Post type
		'context'    => 'normal',
		'priority'   => 'core',
		'show_names' => true, // Show field names on the left
		'fields'     => array(		
			array(
				'name' => esc_html__( 'Alternative Link', 'you' ),
				'id'   => $prefix . 'altlink',
				'type' => 'text',
			),
			array(
				'name'    => esc_html__( 'Disable Link', 'you' ),
				'id'      => $prefix . 'disablegallink',
				'type'    => 'radio_inline',
				'std'		  => 'off',
				'options' => array(
					array( 'name' => esc_html__( 'Disable', 'you' ), 'value' => 'off', ),
					array( 'name' => esc_html__( 'Enable', 'you' ), 'value' => 'yes', ),
				),
			),
			array(
				'name' => esc_html__( 'CSS Classes', 'you' ),
				'plac' => 'Comma separate classes',
				'id'   => $prefix . 'cssclasses',
				'type' => 'text',
			),			
		)
	);

	return $meta_boxes;
}

add_action( 'init', 'acoda_initialize_cmb_meta_boxes', 9999 );
/**
 * Initialize the metabox class.
 */
function acoda_initialize_cmb_meta_boxes() {
	//$do_not_save = 'yes';
	if ( ! class_exists( 'cmb_Meta_Box' ) )
	{
		require_once get_template_directory() . '/lib/adm/metabox-options/init.php';
	}
}