<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$optionsframework_settings = get_option( 'optionsframework' ); 
	$optionsframework_settings['id'] =  ACODA_THEME_PREFIX;
	update_option( 'optionsframework', $optionsframework_settings );
}

function of_get_default( $option ) {
     $defaults = optionsframework_options();
     if ( isset( $defaults[$option]['std'] ) ) {
          return $defaults[$option]['std'];
     }
     return false; // default if no std is set
}

function optionsframework_options() {

	// WP Editor data
	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/lib/adm/images/';	
	
	$theme = wp_get_theme();
	$theme_name = $theme->Name;

	
	global $demo_data_reqs;
	
	$allowed_tags = wp_kses_allowed_html();
	
	// Demo Data
	$demo_data_reqs = array( 
		'message' =>  wp_kses( __('WARNING:||Importing Demo Content will import sliders, pages, posts, theme options, widgets, sidebars and other settings. This will replace all current Theme Options. It can also take sometime to complete.||DO NOT REFRESH the page, unless it has been over 5 minutes.||ACTIVATE PLUGINS:||Please ensure the following plugins are active before installing the demo.||To install plugins, goto Appearance > Install Plugins.||', 'you'), $allowed_tags ),
		'wait' =>  wp_kses( __('<span class="dashicons dashicons-info"></span> <strong>Please wait</strong>, this may take a few minutes. Depending on your server, If this is not complete after 5 minutes, you may need to click re-click the "Install" button once more.', 'you'), $allowed_tags ),		
		'demos' => array(
			'demo_0' => array(
				'name' => 'Classic',
				'reqplugins' => 'Visual Composer|bbPress|WooCommerce|Contact Form 7|Portfolio|ACODA Typewriter|ACODA Pricing Table|ACODA Counters|Revolution Slider',
				'url' => 'http://you.acoda.com/responsive-wordpress-theme',
			),
			'demo_17' => array(
				'name' => 'Photography - Dark',
				'reqplugins' => 'Visual Composer|Contact Form 7|Acoda Typewriter|Acoda Counters|Portfolio',
				'url' => 'http://you.acoda.com/dark-photography-wordpress-theme/'
			),	
			'demo_16' => array(
				'name' => 'Artist - DJ',
				'reqplugins' => 'Visual Composer|Contact Form 7|Acoda Typewriter|Acoda Counters|Gigatools',
				'url' => 'http://you.acoda.com/artist-dj-wordpress-theme/'
			),			
			'demo_13' => array(
				'name' => 'Construction',
				'reqplugins' => 'Visual Composer|Contact Form 7|Portfolio|Acoda Counters',
				'url' => 'http://you.acoda.com/construction-wordpress-theme/'
			),
			'demo_14' => array(
				'name' => 'Photography',
				'reqplugins' => 'Visual Composer|Contact Form 7|Portfolio|ACODA Pricing Table',
				'url' => 'http://you.acoda.com/clean-photography-wordpress-theme/'
			),	
			'demo_15' => array(
				'name' => 'Agency',
				'reqplugins' => 'Visual Composer|Contact Form 7|Portfolio|ACODA Pricing Table|Acoda Counters',
				'url' => 'http://you.acoda.com/clean-agency-wordpress-theme/'
			),			
			'demo_8' => array(
				'name' => 'Portfolio',
				'reqplugins' => 'Visual Composer|Contact Form 7|Portfolio|Acoda Counters|ACODA Pricing Table',
				'url' => 'http://you.acoda.com/clean-freelancer/'
			),			
			'demo_12' => array(
				'name' => 'Clean Fashion Shop',
				'reqplugins' => 'Visual Composer|Contact Form 7|WooCommerce',
				'url' => 'http://you.acoda.com/clean-fashion-shop/'
			),				
			'demo_2' => array(
				'name' => 'Agency',
				'reqplugins' => 'Visual Composer|Contact Form 7|Portfolio|ACODA Typewriter',
				'url' => 'http://you.acoda.com/agency-wordpress-theme/'
			),
			'demo_3' => array(
				'name' => 'App',
				'reqplugins' => 'Visual Composer|Contact Form 7|ACODA Typewriter',
				'url' => 'http://you.acoda.com/app-landing-page/'
			),
			'demo_4' => array(
				'name' => 'Fitness',
				'reqplugins' => 'Visual Composer|Contact Form 7|ACODA Typewriter|ACODA Pricing Table',
				'url' => 'http://you.acoda.com/fitness-wordpress-theme/'
			),
			'demo_5' => array(
				'name' => 'Fashion',
				'reqplugins' => 'Visual Composer',
				'url' => 'http://you.acoda.com/magazine-wordpress-theme/'
			),	
			'demo_6' => array(
				'name' => 'Restaurant',
				'reqplugins' => 'Visual Composer',
				'url' => 'http://you.acoda.com/restaurant-wordpress-theme/'
			),												
			'demo_7' => array(
				'name' => 'Shop',
				'reqplugins' => 'Visual Composer|Contact Form 7|WooCommerce|Slider Revolution',
				'url' => 'http://you.acoda.com/bike-shop-wordpress-theme/'
			),							
			'demo_9' => array(
				'name' => 'Barber Shop',
				'reqplugins' => 'Visual Composer|Contact Form 7',
				'url' => 'http://you.acoda.com/barber-shop-wordpress-theme/'
			),	
			'demo_10' => array(
				'name' => 'Photography',
				'reqplugins' => 'Visual Composer|Contact Form 7',
				'url' => 'http://you.acoda.com/photography-wordpress-theme/'
			),	
			'demo_11' => array(
				'name' => 'Law Firm',
				'reqplugins' => 'Visual Composer|Contact Form 7',
				'url' => 'http://you.acoda.com/law-firm-wordpress-theme/'
			),	
			'demo_1' => array(
				'name' => 'Classic Yellow',
				'reqplugins' => 'Visual Composer|bbPress|WooCommerce|Contact Form 7|Portfolio|ACODA Typewriter|ACODA Pricing Table|ACODA Counters',
				'url' => 'http://you.acoda.com/',
			),														
		)
	);
	
	$demos 		= $demo_data_reqs['demos'];
	$demo_html	= '';
	
	foreach( $demos as $demo => $data )
	{
		$demo_html .= '
		<div class="demo-section">
		<img src="'. get_template_directory_uri() .'/demos/'. $demo .'/preview.png" />
		<h4>'. esc_html( $data['name'] )  .'</h4>
		<a href="#'. esc_attr( $demo ) .'" class="import-demo button button-primary">'. esc_html__( 'Install', 'you' ) .'</a> <a href="#'. esc_attr( $data['url'] ) .'" target="_blank" class="button">'. esc_html__( 'Preview', 'you' ) .'</a>
		</div>		
		';
	}
	
	
	// Page Layout
	$page_layout_array = array(
		'layout_one' 		=> esc_html__('No Sidebar', 'you'),
		'layout_two' 		=> esc_html__('1x Left Sidebar', 'you'),
		'layout_three' 	=> esc_html__('2x Left Sidebar', 'you'),
		'layout_four' 		=> esc_html__('1x Right Sidebar', 'you'),	
		'layout_five' 		=> esc_html__('2x Right Sidebar', 'you'),
		'layout_six' 		=> esc_html__('Left + Right Sidebar', 'you') 			 			 			 			 		 
	);			

	// Columns data
	$columns_array = array(
		'1' => esc_html__('One', 'you'),
		'2' => esc_html__('Two', 'you'),
		'3' => esc_html__('Three', 'you'),
		'4' => esc_html__('Four', 'you'),
	);

	// Sidebar data
	$sidebars = ( of_get_option('sidebars_num') !='' ? of_get_option('sidebars_num') : 2 );
	
	for ( $i=1; $i <= $sidebars; $i++ )
	{
		 $sidebar_array['Sidebar'.$i] = sprintf( __('Sidebar %d', 'you'), $i );
	}
	
	$post_formats = get_theme_support( 'post-formats' );

	foreach( $post_formats[0] as $format )
	{
		 $format_array[$format] = $format;
	}	

	// Author Bio
	$author_bio_array = array(
		'posts' => esc_html__('Posts', 'you'),
		'enable' => esc_html__('Posts &amp; Pages', 'you'),
		'disable' => esc_html__('Disable', 'you'),
	);

	// Twitter Fedd
	$twitter_feed_array = array(
		'none' => esc_html__('Disabled', 'you'),
		'pagetop' => esc_html__('Top', 'you'),
		'pagebot' => esc_html__('Bottom', 'you'),
	);	

	// Social Icon data
	$social_icon_array = acoda_social_icon_data();

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category){
		$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	$options = array();

	$options[] = array(
		'name' => esc_html__('Help & Demo Import', 'you'),
		'type' => 'heading'
	);	

	$options[] = array(
		'name' => esc_html__('Documentation', 'you'),
		'type' => 'info',
		'desc' => sprintf(  wp_kses( __('<p>View the interactive online Documentation below. Alternatively, if you can not find what you are looking for, visit the Help Center.</p>
		<a target="_blank" href="http://docs.acoda.com/%s/" class="documentation_link button button-primary">Interactive Documentation</a> | <a target="_blank" href="http://acoda.com/forums/" class="documentation_link button button-primary">Help Center</a>
		', 'you'), $allowed_tags ), strtolower($theme_name) )	
	);	

	$options[] = array(
		'name' => esc_html__('Install Demo Content', 'you'),
		'type' => 'info',
		'desc' =>  '<p><div class="ajax-message"></div></p>'. $demo_html,			
	);	

	$options[] = array(
		'name' => esc_html__('General', 'you'),
		'type' => 'heading'
	);	

	$options['site_layout'] = array(
		'name' => esc_html__('Site Layout', 'you'),
		'desc' => '',
		'id' => 'site_layout',
		'std' => 'wide',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'wide' => esc_html__('Wide', 'you'),
			'boxed' => esc_html__('Boxed', 'you'),
		)	
	);		
	
	$options['max_site_width'] = array(
		'name' => esc_html__('Maximum Site Width', 'you'),
		'desc' => esc_html__('Default is 1440', 'you'),
		'id' => 'max_site_width',
		'class' => 'mini', //mini, tiny, small
		'type' => 'text'
	);		

	$options['pagelayout'] = array(
		'name' => 'Default Page Format',
		'desc' => '',
		'id' => 'pagelayout',
		'std' => 'layout_one',
		'type' => "select",
		'class' => 'mini',
		'options' => $page_layout_array
	);		

	$options['sidebars_num'] = array(
		'name' => esc_html__('Number of Sidebars', 'you'),
		'desc' => esc_html__('Default is 2', 'you'),
		'id' => 'sidebars_num',
		'std' => '',
		'class' => 'mini', //mini, tiny, small
		'type' => 'text'
	);	

	$options['breadcrumb'] = array(
		'name' => esc_html__('Breadcrumbs', 'you'),
		'desc' => '',
		'id' => 'breadcrumb',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);

	$options['author_bio'] = array(
		'name' => esc_html__('Show Author Bio', 'you'),
		'desc' => esc_html__('Enable this option to display author bio information.', 'you'),
		'id' => 'author_bio',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => $author_bio_array
	);	

	$options['widget_tag'] = array(
		'name' => esc_html__('Widget Title Tag', 'you'),
		'id' => 'widget_tag',
		'std' => 'h4',
		'type' => 'select',
		'desc' => esc_html__('Set the Title tag for Widgets.', 'you'),
		'class' => 'mini',
		'options' => array(
			'p' => esc_html__('p', 'you'),
			'h3' => esc_html__('h3', 'you'),
			'h4' => esc_html__('h4', 'you'),
			'h5' => esc_html__('h5', 'you'),
			'h6' => esc_html__('h6', 'you'),
		)	
	);

	$options['animate_type'] = array(
		'name' => esc_html__('Element Animation', 'you'),
		'id' => 'animate_type',
		'std' => 'animate-3d',
		'type' => 'select',
		'desc' => esc_html__('Set the animation type for the Menu, Dock Panels and Grid Loading.', 'you'),
		'class' => 'mini',
		'options' => array(
			'animate-3d' => esc_html__('3d', 'you'),
			'animate-slide' => esc_html__('Slide', 'you'),
			'animate-fade' => esc_html__('Fade', 'you')
		)	
	);		

	$options['elem_border_radius'] = array(
		'name' => esc_html__('Element Border Radius', 'you'),
		'desc' => esc_html__('Set rounded edges for elements across the site - 0 is square.', 'you'),
		'id' => 'elem_border_radius',
		'std' => '4px',
		'class' => 'mini',
		'type' => 'text'
	);		

	$options[] = array(
		'name' => esc_html__('Search', 'you'),
		'type' => 'info',
	);	

	$options['search_placeholder'] = array(
		'name' => esc_html__('Search Placeholder Text', 'you'),
		'id' => 'search_placeholder',
		'std' => '',
		'class' => 'mini', //mini, tiny, small
		'type' => 'text'
	);		

	$options[] = array(
		'name' => esc_html__('Preloader', 'you'),
		'type' => 'info',
	);		

	$options['preloader'] = array(
		'name' => esc_html__('Preloader Type', 'you'),
		'desc' => '',
		'id' => 'preloader',
		'std' => 'preloader_1',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'preloader_1' => esc_html__('Preloader 1', 'you'),
			'preloader_2' => esc_html__('Preloader 2', 'you'),
			'preloader_3' => esc_html__('Preloader 3', 'you'),
			'disable' => esc_html__('Disable', 'you')
		)	
	);	

	$options[] = array(
		'name' => esc_html__('Lightbox', 'you'),
		'type' => 'info',
	);	

	$options['lightbox_script'] = array(
		'name' => esc_html__('FancyBox Lightbox', 'you'),
		'desc' => '',
		'id' => 'lightbox_script',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);
	
	$options['lightbox_classes'] = array(
		'name' => esc_html__('Lightbox Classes', 'you'),
		'id' => 'lightbox_classes',
		'desc' => wp_kses( __('Add custom link classes to activate Lightbox. e.g. <strong>.gallery-item a</strong> - Comma separate for multiple classes.', 'you'), $allowed_tags ),
		'std' => '',
		'type' => 'text'
	);	

	$options[] = array(
		'name' => esc_html__('First Image Detection', 'you'),
		'type' => 'info',
	);	

	$options['firstimage_detect'] = array(
		'name' => esc_html__('Use First Image of Posts', 'you'),
		'desc' => '',
		'id' => 'firstimage_detect',
		'std' => 'disable',
		'desc' => esc_html__('Allows the detection of the first image within the post to be used as a Featured Image.', 'you'),
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);

	$options[] = array(
		'name' => esc_html__('Dock Bar', 'you'),
		'type' => 'heading',
	);		
			
	$options['dockicon_position'] = array(
		'name' => esc_html__('Dock Bar Position', 'you'),
		'id' => 'dockicon_position',
		'std' => 'dock_layout_4',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('Choose the position of the Header Dock Icons ( Search, Social Icons etc ).', 'you'),	
		'options' => array(
			'dock_layout_4' => esc_html__('Header', 'you'),
			'dock_layout_1' => esc_html__('Dock Bar Top', 'you'),
			'dock_layout_1 dock_float' => esc_html__('Dock Bar Top Float', 'you'),
			'dock_layout_2' => esc_html__('Dock Bar Left', 'you'),
			'dock_layout_2 dock_float' => esc_html__('Dock Bar Left Float', 'you'),
			'dock_layout_3' => esc_html__('Dock Bar Right', 'you'),
			'dock_layout_3 dock_float' => esc_html__('Dock Bar Right Float', 'you'),
		)	
	);	

	$options['dockicon_panels'] = array(
		'name' => esc_html__('Dock Panel Style', 'you'),
		'id' => 'dockicon_panels',
		'std' => 'dockpanel_type_1',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('Choose how to display the Dock Panels when a Dock Icon is selected.', 'you'),	
		'options' => array(
			'dockpanel_type_1' => esc_html__('Pointer', 'you'),
			'dockpanel_type_2' => esc_html__('Flat', 'you'),
			'dockpanel_type_3' => esc_html__('Fullscreen', 'you'),
		)	
	);

	$options['enable_search'] = array(
		'name' => esc_html__('Display Search', 'you'),
		'id' => 'enable_search',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you'),
		)	
	);		

	$options['dockicon_infopanel'] = array(
		'name' => esc_html__('Info Dock Panel', 'you'),
		'id' => 'dockicon_infopanel',
		'std' => '',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('For Desktop only - add Widgets via Appearance > Widgets > Information Panel.', 'you'),	
		'options' => array(
			'' => esc_html__('Static', 'you'),
			'enable' => esc_html__('Dock Icon', 'you'),
		)	
	);		

	$options['dockicon_info_icon'] = array(
		'name' => esc_html__('Info Dock Icon', 'you'),
		'desc' =>  wp_kses( __('Set a <a href="http://fortawesome.github.io/Font-Awesome/icons/" target=\"_blank\">Font Awesome</a> Icon for the Information Dock Icon. Default is <strong>fa-info</strong>', 'you'), $allowed_tags ),	
		'id' => 'dockicon_info_icon',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);	

	$options['dockicon_menu_icon'] = array(
		'name' => esc_html__('Menu Dock Icon', 'you'),
		'desc' =>  wp_kses( __('Set a <a href="http://fortawesome.github.io/Font-Awesome/icons/" target=\"_blank\">Font Awesome</a> Icon for the Menu Dock Icon. Default is <strong>fa-bars</strong>', 'you'), $allowed_tags ),	
		'id' => 'dockicon_menu_icon',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);	

	$options['dockicon_menu_text'] = array(
		'name' => esc_html__('Menu Dock Icon Text', 'you'),
		'desc' => esc_html__('Add description text below icon e.g. MENU', 'you'),	
		'id' => 'dockicon_menu_text',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);									

	$options[] = array(
		'name' => esc_html__('Header', 'you'),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => esc_html__('Display', 'you'),
		'type' => 'info',
	);	

	$options['header_display'] = array(
		'name' => esc_html__('Header Display', 'you'),
		'id' => 'header_display',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('Enable', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options[] = array(
		'name' => esc_html__('Layout', 'you'),
		'type' => 'info',
	);	

	$options['header_width'] = array(
		'name' => esc_html__('Width', 'you'),
		'id' => 'header_width',
		'std' => 'wide',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'wide' => esc_html__('Site Width', 'you'),
			'fullwidth' => esc_html__('Full Width', 'you'),
		)	
	);

	$options['header_layout'] = array(
		'name' => esc_html__('Horizontal Layout', 'you'),
		'id' => 'header_layout',
		'std' => 'dock_layout_1',
		'type' => 'select',
		'class' => '',
		'options' => array(
			'layout_1' => esc_html__('Logo Left | Menu Right', 'you'),
			'layout_2' => esc_html__('Menu Left | Logo Right', 'you'),
			'layout_3' => esc_html__('Menu Center | Logo Center', 'you'),
		)	
	);

	$options['header_layout_vertical'] = array(
		'name' => esc_html__('Vertical Layout', 'you'),
		'id' => 'header_layout_vertical',
		'std' => 'valign_1',
		'type' => 'select',
		'class' => '',
		'options' => array(
			'vertical_layout_1' => esc_html__('Top + Auto Height', 'you'),
			'vertical_layout_1 height_30' => esc_html__('Top + 30% Height', 'you'),
			'vertical_layout_1 height_50' => esc_html__('Top + 50% Height', 'you'),
			'vertical_layout_1 height_100' => esc_html__('Top + 100% Height', 'you'),
			'vertical_layout_2 height_30' => esc_html__('Middle + 30% Height', 'you'),
			'vertical_layout_2 height_50' => esc_html__('Middle + 50% Height', 'you'),
			'vertical_layout_2 height_100' => esc_html__('Middle + 100% Height', 'you'),
		)	
	);	
	
	$options['header_float'] = array(
		'name' => esc_html__('Floating Header', 'you'),
		'id' => 'header_float',
		'std' => '',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'' => esc_html__('Disabled', 'you'),
			'header_float' => esc_html__('Float', 'you'),
			'header_float transparent_default_font' => esc_html__('Float + Transparent / Custom Font Color', 'you'),
			'header_float transparent' => esc_html__('Float + Transparent / Normal Font Color', 'you'),
		)	
	);	
	

	$options[] = array(
		'name' => esc_html__('Subheader', 'you'),
		'type' => 'info',
	);	
			
	$options['title_layout'] = array(
		'name' => esc_html__('Title Layout', 'you'),
		'id' => 'title_layout',
		'std' => 'dock_layout_1',
		'type' => 'select',
		'class' => 'medium',
		'options' => array(
			'layout_1' => esc_html__('Title ( Left ) / Breadcrumbs ( Right )', 'you'),
			'layout_2' => esc_html__('Breadcrumbs ( Left ) / Title ( Right )', 'you'),
			'layout_3' => esc_html__('Title ( Center ) / Breadcrumbs ( Center )', 'you')
		)	
	);	

	$options['subheader_height'] = array(
		'name' => esc_html__('Subheader Height', 'you'),
		'desc' => '',
		'id' => 'subheader_height',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);		
	
	$options[] = array(
		'name' => esc_html__('Branding / Logo', 'you'),
		'type' => 'info',
	);	

	$options['logo_display'] = array(
		'name' => esc_html__('Display Logo', 'you'),
		'id' => 'logo_display',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);	

	$options['logo_height'] = array(
		'name' => esc_html__('Logo Height', 'you'),
		'desc' => '',
		'id' => 'logo_height',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);		

	$options['header_tagline'] = array(
		'name' => esc_html__('Display Tagline', 'you'),
		'id' => 'header_tagline',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'enable' => esc_html__('On', 'you')
		)	
	);	

	$options['branding_url'] = array(
		'name' => esc_html__('Logo', 'you'),
		'desc' => '',
		'std' => '',
		'id' => 'branding_url',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => esc_html__('Retina Logo', 'you'),
		'desc' => '',
		'id' => 'branding_2x',
		'type' => 'upload'
	);				

	$options[] = array(
		'name' => esc_html__('Main Menu', 'you'),
		'type' => 'info'
	);

	$options['dockicon_menu'] = array(
		'name' => esc_html__('Move to Dock Bar', 'you'),
		'id' => 'dockicon_menu',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'enable' => esc_html__('On', 'you')
		)	
	);	

	$options['sticky_menu'] = array(
		'name' => esc_html__('Sticky Menu', 'you'),
		'id' => 'sticky_menu',
		'std' => 'enable',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);		

	$options['menu_height'] = array(
		'name' => esc_html__('Menu Height', 'you'),
		'desc' => '',
		'id' => 'menu_height',
		'std' => '',
		'class' => 'mini',
		'type' => 'text'
	);			

	$options[] = array(
		'name' => esc_html__('Header Widget', 'you'),
		'type' => 'info'
	);	

	$options['header_widget_width'] = array(
		'name' => esc_html__('Width', 'you'),
		'desc' => '',
		'id' => 'header_widget_width',
		'std' => 'normal',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'width_100' => '100%',
			'width_75' => '75%',
			'width_50' => '50%'
		)
	);	
	
	$options['header_widget_align'] = array(
		'name' => esc_html__('Text Align', 'you'),
		'desc' => '',
		'id' => 'header_widget_align',
		'std' => 'normal',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'center' =>  esc_html__('Center', 'you'),
			'left' => esc_html__('Left', 'you'),
			'right' => esc_html__('Right', 'you'),
		)
	);		
		
	$options[] = array(
		'name' => esc_html__('Footer', 'you'),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => esc_html__('Main Footer', 'you'),
		'type' => 'info',
	);		

	$options['mainfooter'] = array(
		'name' => esc_html__('Display Footer', 'you'),
		'id' => 'mainfooter',
		'std' => 'enable',
		'type' => 'radio',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);	

	$options['footer_columns_num'] = array(
		'name' => esc_html__('Footer Columns', 'you'),
		'id' => 'footer_columns_num',
		'std' => '4',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $columns_array
	);

	$options[] = array(
		'name' => esc_html__('Lower Footer', 'you'),
		'type' => 'info',
	);

	$options['lowerfooter'] = array(
		'name' => esc_html__('Display Lower Footer', 'you'),
		'id' => 'lowerfooter',
		'std' => 'enable',
		'type' => 'radio',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);

	$options['lowfooterleft'] = array(
		'name' => esc_html__('Left Column', 'you'),
		'id' => 'lowfooterleft',
		'type' => 'textarea',
		'settings' => $wp_editor_settings 
	);

	$options['lowfooterright'] = array(
		'name' => esc_html__('Right Column', 'you'),
		'id' => 'lowfooterright',
		'type' => 'textarea',
		'settings' => $wp_editor_settings 
	);


	$options[] = array(
		'name' => esc_html__('Blog', 'you'),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => esc_html__('Post Content', 'you'),
		'id' => 'arhpostcontent',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'excerpt' =>  esc_html__('Excerpt', 'you'),
			'full_post' => esc_html__('Full Post', 'you'),
		)
	);

	$options[] = array(
		'name' => esc_html__('Layout', 'you'),
		'type' => 'info',
	);	

	$options['arhlayout'] = array(
		'name' => esc_html__('Default Post Layout', 'you'),
		'desc' => '',
		'id' => 'arhlayout',
		'std' => 'layout_one',
		'type' => "select",
		'class' => 'mini',
		'options' => array(
			'layout_one' 		=> esc_html__('No Sidebar', 'you'),
			'layout_zero' 		=> esc_html__('No Sidebar + Fullwidth', 'you'),
			'layout_two' 		=> esc_html__('1x Left Sidebar', 'you'),
			'layout_three' 	=> esc_html__('2x Left Sidebar', 'you'),
			'layout_four' 		=> esc_html__('1x Right Sidebar', 'you'),	
			'layout_five' 		=> esc_html__('2x Right Sidebar', 'you'),
			'layout_six' 		=> esc_html__('Left + Right Sidebar', 'you') 			 			 			 			 		 
		)
	);

	$options['archcolone'] = array(
		'name' => esc_html__('Column 1 Sidebar', 'you'),
		'id' => 'archcolone',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $sidebar_array
	);

	$options['archcoltwo'] = array(
		'name' => esc_html__('Column 2 Sidebar', 'you'),
		'id' => 'archcoltwo',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $sidebar_array
	);	

	$options['arhpostdisplay'] = array(
		'name' => esc_html__('Layout Format', 'you'),
		'desc' => '',
		'id' => 'arhpostdisplay',
		'std' => 'masonrygrid',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'normal' => esc_html__('Normal', 'you'),
			'grid' => esc_html__('Grid', 'you'),
			'masonrygrid' => esc_html__('Masonry Grid', 'you'),
		)	
	);

	$options['post_layout_style'] = array(
		'name' => esc_html__('Boxed Post Style', 'you'),
		'desc' => '',
		'id' => 'post_layout_style',
		'std' => 'boxed_archive',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'boxed' => esc_html__('Single & Archive', 'you'),
			'boxed_single' => esc_html__('Single', 'you'),
			'boxed_archive' => esc_html__('Archive', 'you'),
			'unboxed' => esc_html__('Disabled', 'you'),
		)	
	);

	$options['arhpostcolumns'] = array(
		'name' => esc_html__('Grid Columns', 'you'),
		'desc' => '',
		'id' => 'arhpostcolumns',
		'std' => 'normal',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'3' => esc_html__('Three', 'you'),
			'2' => esc_html__('Two', 'you'),
			'4' => esc_html__('Four', 'you'),
			'5' => esc_html__('Five', 'you'),
			'6' => esc_html__('Six', 'you'),
		)
	);
	
	$options['blog_search'] = array(
		'name' => esc_html__('Search', 'you'),
		'desc' => '',
		'id' => 'blog_search',
		'std' => 'disabled',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('Add a normal Search Bar or a Search Filter option. Search Filter will filter the posts on screen as you type.', 'you'),
		'options' => array(
			'disabled' => esc_html__('Disabled', 'you'),
			'search' => esc_html__('Search Bar', 'you'),
			'search_filter' => esc_html__('Search Filter', 'you'),
			'search_filter_highlight' => esc_html__('Search Filter + Highlight', 'you'),
		)	
	);	

	$options['blog_pagination'] = array(
		'name' => esc_html__('Pagination', 'you'),
		'desc' => '',
		'id' => 'blog_pagination',
		'std' => 'click_load',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'click_load' => esc_html__('Ajax Click Load', 'you'),
			'scroll_load' => esc_html__('Ajax Scroll Load', 'you'),
			'page_numbers' => esc_html__('Page Numbers', 'you'),
		)
	);

	$options['blog_title'] = array(
		'name' => esc_html__('Blog Index Title', 'you'),
		'desc' => '',
		'id' => 'blog_title',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('If "Your latest posts" are set to the home page ( Settings > Reading ), you can choose whether to display the Site title or not.', 'you'),
		'options' => array(
			'enable' => esc_html__('Enable', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options['posttitle_position'] = array(
		'name' => esc_html__('Single Title Position', 'you'),
		'desc' => '',
		'id' => 'posttitle_position',
		'std' => '',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'' => esc_html__('Header', 'you'),
			'content' => esc_html__('Content', 'you'),
		)	
	);			

	$options[] = array(
		'name' => esc_html__('Featured Image', 'you'),
		'type' => 'info',
	);		

	$options['arhpostimage'] = array(
		'name' => esc_html__('Featured Image', 'you'),
		'id' => 'arhpostimage',
		'type' => 'select',
		'class' => 'mini',
		'options' => array (
			'' => esc_html__('Single & Archive', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)
	);		

	$options[] = array(
		'name' => esc_html__('Share + Related Posts', 'you'),
		'type' => 'info',
	);		

	$options['share_post'] = array(
		'name' => esc_html__('Share Post', 'you'),
		'desc' => '',
		'id' => 'share_post',
		'std' => 'disable',
		'desc' => wp_kses( __('Add Social Icons to the bottom of Posts - Uses selected Social Icons from the <strong>Social Media</strong> admin section.', 'you') ,$allowed_tags ),
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('Enable', 'you'),
			'disable' => esc_html__('Disable', 'you')
		)	
	);		

	$options['related_posts'] = array(
		'name' => esc_html__('Related Posts', 'you'),
		'id' => 'related_posts',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('Enable', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options[] = array(
		'name' => esc_html__('Metadata', 'you'),
		'type' => 'info',
	);		

	/*$options['metadata_position'] = array(
		'name' => esc_html__('Position', 'you'),
		'id' => 'metadata_position',
		'std' => 'enable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'' => esc_html__('Below Post Content', 'you'),
			'layout_2' => esc_html__('Below Post Title', 'you'),
		)	
	);		*/

	$options['meta_date_format_archive'] = array(
		'name' => esc_html__('Archive Date Format', 'you'),
		'id' => 'meta_date_format_archive',
		'std' => 'd M',
		'desc' =>  wp_kses( __('See WordPress <a href="http://codex.wordpress.org/Formatting_Date_and_Time">Date Formats</a> for reference.', 'you'), $allowed_tags ),
		'class' => 'mini',	
		'type' => 'text',
	);	

	$options['meta_date_format_single'] = array(
		'name' => esc_html__('Single Date Format', 'you'),
		'id' => 'meta_date_format_single',
		'std' => 'd F Y',
		'desc' =>  wp_kses( __('See WordPress <a href="http://codex.wordpress.org/Formatting_Date_and_Time">Date Formats</a> for reference.', 'you'), $allowed_tags ),
		'class' => 'mini',	
		'type' => 'text',
	);		

	$options['meta_date_position'] = array(
		'name' => esc_html__('Date Position', 'you'),
		'id' => 'meta_date_position',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Title', 'you'),
			'metadata' => esc_html__('Metadata Area', 'you'),
		)	
	);	

	$options['meta_date'] = array(
		'name' => esc_html__('Display Date', 'you'),
		'id' => 'meta_date',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options['meta_author'] = array(
		'name' => esc_html__('Display Author', 'you'),
		'id' => 'meta_author',
		'std' => '',
		'class' => 'mini',		
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);		

	$options['meta_categories'] = array(
		'name' => esc_html__('Display Categories', 'you'),
		'id' => 'meta_categories',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	
	
	$options['meta_tags'] = array(
		'name' => esc_html__('Display Tags', 'you'),
		'id' => 'meta_tags',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options['meta_like'] = array(
		'name' => esc_html__('Display Like', 'you'),
		'id' => 'meta_like',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);	

	$options['meta_comments'] = array(
		'name' => esc_html__('Display Comments', 'you'),
		'id' => 'meta_comments',
		'std' => '',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'' => esc_html__('Single & Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);			

	$options[] = array(
		'name' => esc_html__('Blog Page Images', 'you'),
		'type' => 'info',
	);	

	$options['archive_img_align'] = array(
		'name' => esc_html__('Image Alignment', 'you'),
		'id' => 'archive_img_align',
		'std' => 'center',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'left' => esc_html__('Left', 'you'),
			'center' => esc_html__('Center', 'you'),
			'right' => esc_html__('Right', 'you')
		)	
	);
	
	$options['blog_lightbox'] = array(
		'name' => esc_html__('Image Lightbox', 'you'),
		'id' => 'blog_lightbox',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'enable' => esc_html__('On', 'you'),
			'disable' => esc_html__('Off', 'you')
		)	
	);	
	
	$options['arhimgeffect'] = array(
		'name' => esc_html__('Image Effect', 'you'),
		'id' => 'arhimgeffect',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'none' => esc_html__('None', 'you'),
			'frame' => esc_html__('Frame', 'you'),
			'blackwhite' =>  esc_html__('Black & White', 'you'),
			'frameblackwhite' => esc_html__('Frame + Black & White', 'you'),
		)
	);

	$options['archive_img_size'] = array(
		'name' => esc_html__('Image Size', 'you'),
		'id' => 'archive_img_size',
		'std' => '',
		'class' => 'mini',
		'type' => 'text',
		'desc' => esc_html__("Enter image size. e.g. 'thumbnail', 'medium', 'large', 'full'. Alternatively enter image size in pixels: 200x100 (Width x Height).", 'you')
	);


	$options[] = array(
		'name' => esc_html__('Single Post Images', 'you'),
		'type' => 'info',
	);	

	$options['post_headerimage'] = array(
		'name' => esc_html__('Image in Header', 'you'),
		'id' => 'post_headerimage',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'enable' => esc_html__('On', 'you')
		)	
	);		
	
	$options['post_lightbox'] = array(
		'name' => esc_html__('Image Lightbox', 'you'),
		'id' => 'post_lightbox',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'lightbox' => esc_html__('On', 'you')
		)	
	);	
	
	$options['postimgeffect'] = array(
		'name' => esc_html__('Image Effect', 'you'),
		'id' => 'postimgeffect',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'none' => esc_html__('None', 'you'),
			'frame' => esc_html__('Frame', 'you'),
			'blackwhite' =>  esc_html__('Black & White', 'you'),
			'frameblackwhite' => esc_html__('Frame + Black & White', 'you'),
		)
	);

	$options['single_img_size'] = array(
		'name' => esc_html__('Image Size', 'you'),
		'id' => 'single_img_size',
		'std' => '',
		'class' => 'mini',		
		'type' => 'text',
		'desc' => esc_html__("Enter image size. e.g. 'thumbnail', 'medium', 'large', 'full'. Alternatively enter image size in pixels: 200x100 (Width x Height).", 'you')
	);
	
	// Portfolio
	$options[] = array(
		'name' => esc_html__('Portfolio', 'you'),
		'type' => 'heading'
	);	

	$options[] = array(
		'name' => esc_html__('Layout', 'you'),
		'type' => 'info',
	);	

	$options['portlayout'] = array(
		'name' => 'Default Post Layout',
		'desc' => '',
		'id' => 'portlayout',
		'std' => 'layout_one',
		'type' => "select",
		'class' => 'mini',
		'options' => $page_layout_array
	);

	$options['portcolone'] = array(
		'name' => esc_html__('Column 1 Sidebar', 'you'),
		'id' => 'portcoltwo',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $sidebar_array
	);

	$options['portcoltwo'] = array(
		'name' => esc_html__('Column 2 Sidebar', 'you'),
		'id' => 'portcoltwo',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $sidebar_array
	);	

	$options['portpostdisplay'] = array(
		'name' => esc_html__('Archive Layout Format', 'you'),
		'desc' => '',
		'id' => 'portpostdisplay',
		'std' => 'masonrygrid',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'masonrygrid' => esc_html__('Masonry Grid', 'you'),
			'normal' => esc_html__('Normal', 'you'),
			'grid' => esc_html__('Grid', 'you')
		)	
	);

	$options['portfolio_layout_style'] = array(
		'name' => esc_html__('Boxed Post Style', 'you'),
		'desc' => '',
		'id' => 'portfolio_layout_style',
		'std' => 'boxed_archive',
		'class' => 'mini',
		'type' => 'select',
		'options' => array(
			'unboxed' => esc_html__('Disabled', 'you'),
			'boxed' => esc_html__('Single & Archive', 'you'),
			'boxed_single' => esc_html__('Single', 'you'),
			'boxed_archive' => esc_html__('Archive', 'you'),
		)	
	);

	$options['portpostcolumns'] = array(
		'name' => esc_html__('Grid Columns', 'you'),
		'desc' => '',
		'id' => 'portpostcolumns',
		'std' => 'normal',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'2' => esc_html__('Two', 'you'),
			'3' => esc_html__('Three', 'you'),
			'4' => esc_html__('Four', 'you'),
			'5' => esc_html__('Five', 'you'),
			'6' => esc_html__('Six', 'you'),
		)
	);

	$options['portfoliopage'] = array(
		'name' => esc_html__('Parent Portfolio Page', 'you'),
		'id' => 'portfoliopage',
		'std' => '',
		'desc' => 'Default is the Archive page.',		
		'class' => 'mini',
		'type' => 'select',
		'options' => $options_pages	
	);	

	$options['portfoliopagelink'] = array(
		'name' => esc_html__('Portfolio Page Link', 'you'),
		'id' => 'portfoliopagelink',
		'std' => '',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'' => esc_html__('Enable', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)	
	);		
	
	$options['portfolio_search'] = array(
		'name' => esc_html__('Search', 'you'),
		'desc' => '',
		'id' => 'portfolio_search',
		'std' => 'disabled',
		'type' => 'select',
		'class' => 'mini',
		'desc' => esc_html__('Add a normal Search Bar or a Search Filter option. Search Filter will filter the posts on screen as you type.', 'you'),
		'options' => array(
			'disabled' => esc_html__('Disabled', 'you'),
			'search' => esc_html__('Search Bar', 'you'),
			'search_filter' => esc_html__('Search Filter', 'you'),
			'search_filter_highlight' => esc_html__('Search Filter + Highlight', 'you'),
		)	
	);	

	$options['portfolio_pagination'] = array(
		'name' => esc_html__('Pagination', 'you'),
		'desc' => '',
		'id' => 'portfolio_pagination',
		'std' => 'click_load',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'click_load' => esc_html__('Ajax Click Load', 'you'),
			'scroll_load' => esc_html__('Ajax Scroll Load', 'you'),
			'page_numbers' => esc_html__('Page Numbers', 'you'),
		)
	);

	$options[] = array(
		'name' => esc_html__('Featured Image', 'you'),
		'type' => 'info',
	);		

	$options['portpostimage'] = array(
		'name' => esc_html__('Featured Image', 'you'),
		'id' => 'portpostimage',
		'type' => 'select',
		'class' => 'mini',
		'options' => array (
			'' => esc_html__('Single & Archive', 'you'),
			'archive' => esc_html__('Archive', 'you'),
			'single' => esc_html__('Single', 'you'),
			'disable' => esc_html__('Disable', 'you'),
		)
	);		

	$options[] = array(
		'name' => esc_html__('Portfolio Archive Images', 'you'),
		'type' => 'info',
	);	

	$options['portfolio_img_align'] = array(
		'name' => esc_html__('Image Alignment', 'you'),
		'id' => 'portfolio_img_align',
		'std' => 'center',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'left' => esc_html__('Left', 'you'),
			'center' => esc_html__('Center', 'you'),
			'right' => esc_html__('Right', 'you')
		)	
	);
	
	$options['portfolio_lightbox'] = array(
		'name' => esc_html__('Image Lightbox', 'you'),
		'id' => 'portfolio_lightbox',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'enable' => esc_html__('On', 'you')
		)	
	);	

	$options['portfolio_img_size'] = array(
		'name' => esc_html__('Image Size', 'you'),
		'id' => 'portfolio_img_size',
		'std' => '',
		'class' => 'mini',
		'type' => 'text',
		'desc' => esc_html__("Enter image size. e.g. 'thumbnail', 'medium', 'large', 'full'. Alternatively enter image size in pixels: 200x100 (Width x Height).", 'you')
	);


	$options[] = array(
		'name' => esc_html__('Single Portfolio Images', 'you'),
		'type' => 'info',
	);	
	
	$options['portfolio_post_lightbox'] = array(
		'name' => esc_html__('Image Lightbox', 'you'),
		'id' => 'portfolio_post_lightbox',
		'std' => 'disable',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'disable' => esc_html__('Off', 'you'),
			'lightbox' => esc_html__('On', 'you')
		)	
	);	

	$options['port_single_img_size'] = array(
		'name' => esc_html__('Image Size', 'you'),
		'id' => 'port_single_img_size',
		'std' => '',
		'class' => 'mini',		
		'type' => 'text',
		'desc' => esc_html__("Enter image size. e.g. 'thumbnail', 'medium', 'large', 'full'. Alternatively enter image size in pixels: 200x100 (Width x Height).", 'you')
	);		

	if ( class_exists( 'bbPress' ) ) { 

		$options[] = array(
			'name' => esc_html__('BBPress', 'you'),
			'type' => 'heading'
		);
	
		$options[] = array(
			'name' => esc_html__('Layout', 'you'),
			'type' => 'info',
		);	
	
		$options['buddylayout'] = array(
			'name' => 'Page Format',
			'desc' => '',
			'id' => 'buddylayout',
			'std' => 'layout_one',
			'type' => "select",
			'class' => 'mini',
			'options' => $page_layout_array
		);
	
		$options['buddycolone'] = array(
			'name' => esc_html__('Column 1 Sidebar', 'you'),
			'id' => 'buddycolone',
			'type' => 'select',
			'class' => 'mini', //mini, tiny, small
			'options' => $sidebar_array
		);
	
		$options['buddycoltwo'] = array(
			'name' => esc_html__('Column 2 Sidebar', 'you'),
			'id' => 'buddycoltwo',
			'type' => 'select',
			'class' => 'mini', //mini, tiny, small
			'options' => $sidebar_array
		);			
	}

	if (class_exists( 'woocommerce' ) ) { 

		$options[] = array(
			'name' => esc_html__('WooCommerce', 'you'),
			'type' => 'heading'
		);
	
		$options[] = array(
			'name' => esc_html__('Layout', 'you'),
			'type' => 'info',
		);	
	
		$options['woocomlayout'] = array(
			'name' => 'Page Format',
			'desc' => '',
			'id' => 'woocomlayout',
			'std' => 'layout_one',
			'type' => "select",
			'class' => 'mini',
			'options' => $page_layout_array
		);
	
		$options['woocomcolone'] = array(
			'name' => esc_html__('Column 1 Sidebar', 'you'),
			'id' => 'woocomcolone',
			'type' => 'select',
			'class' => 'mini', //mini, tiny, small
			'options' => $sidebar_array
		);
	
		$options['woocomcoltwo'] = array(
			'name' => esc_html__('Column 2 Sidebar', 'you'),
			'id' => 'woocomcoltwo',
			'type' => 'select',
			'class' => 'mini', //mini, tiny, small
			'options' => $sidebar_array
		);
		
		$options['woocommerce_cart'] = array(
			'name' => 'Cart Dock Icon',
			'desc' => '',
			'id' => 'woocommerce_cart',
			'std' => 'enable',
			'type' => "radio",
			'options' => array(
				'enable' => esc_html__('On', 'you'),
				'disable' => esc_html__('Off', 'you')		
			)
		);	

		$options['woocomsearch'] = array(
			'name' => 'Search Products Only',
			'desc' => '',
			'id' => 'woocomsearch',
			'std' => '',
			'desc' => esc_html__('Change the Header Search Bar to search for Products only.', 'you'),
			'type' => "radio",
			'options' => array(
				'enable' => esc_html__('On', 'you'),
				'' => esc_html__('Off', 'you')		
			)
		);		

		$options['share_product'] = array(
			'name' => esc_html__('Share Product', 'you'),
			'desc' => '',
			'id' => 'share_product',
			'std' => 'disable',
			'desc' => wp_kses( __('Add Social Icons to the bottom of Products - Uses selected Social Icons from the <strong>Social Media</strong> Theme Options.', 'you') ,$allowed_tags ),
			'type' => 'select',
			'class' => 'mini',
			'options' => array(
				'enable' => esc_html__('Enable', 'you'),
				'disable' => esc_html__('Disable', 'you')
			)	
		);			
	}	
	
	
	$options[] = array(
		'name' => esc_html__('Social Media', 'you'),
		'type' => 'heading'
	);

	$options['social_info'] = array(
		'name' => esc_html__('Social Icons', 'you'),
		'type' => 'info',
		'id' => 'social_info',
	);	

	$options['display_socialicons'] = array(
		'name' => esc_html__('Dock Social Icons', 'you'),
		'desc' => '',
		'id' => 'display_socialicons',
		'std' => 'off',
		'desc' => esc_html__('Add selected social icons to the Header area.', 'you'),
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'off' => esc_html__('Off', 'you'),
			'yes' => esc_html__('On', 'you')
		)	
	);
	
	$options['socialicons_share'] = array(
		'name' => esc_html__('Share Icon', 'you'),
		'desc' => '',
		'id' => 'socialicons_share',
		'std' => 'off',
		'type' => 'select',
		'class' => 'mini',
		'options' => array(
			'off' => esc_html__('Off', 'you'),
			'on' => esc_html__('On', 'you')
		)	
	);		

	$options['socialicons_color'] = array(
		'name' => esc_html__('Social Icons Color', 'you'),
		'id' => 'socialicons_color',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => array (
			'' => 'Default',
			'color' => esc_html__('Color', 'you'),
			'color_hover' => esc_html__('Color on Hover', 'you'),
		)
	);	

	foreach ( $social_icon_array as $key => $socialicon )
	{
		$social_array[ strtolower( str_replace('.','',$socialicon['name'] ) ) ] = $socialicon['name'];
	}
	
	$options['socialicons'] = array(
		'name' => esc_html__('Enable Social Icons', 'you'),
		'id' => 'socialicons',
		'std' => '',
		'type' => 'multicheck',
		'options' => $social_array		
	);

	$options[] = array(
		'name' => esc_html__('Social Icon URL\'s', 'you'),
		'type' => 'info',
		'id' => 'socialurl_info',		
	);			
	
	foreach ( $social_icon_array as $key => $socialicon )
	{
		if( $key != 'sociallink_likes' )
		{
			$options[] = array(
				'name' => $socialicon['name'],
				'id' => $key,
				'std' => $socialicon['path'],
				'type' => 'text'
			);
		}
	}

	$options[] = array(
		'name' => esc_html__('Custom CSS', 'you'),
		'type' => 'heading'
	);

	$options['header_css'] = array(
		'name' => esc_html__('Custom CSS', 'you'),
		'id' => 'header_css',
		'type' => 'textarea_css',
		'settings' => array(
			'rows' => '20'
		)	
	);	

	$options['responsive_css'] = array(
		'name' => esc_html__('Mobile CSS', 'you'),
		'id' => 'responsive_css',
		'desc' => wp_kses( __('CSS for Devices with a maximum width of 1024px.</strong>', 'you'), $allowed_tags ),
		'type' => 'textarea_css',
		'settings' => array(
			'rows' => '20'
		)	
	);		

	return $options;
}